# NRSurrogate catalog
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.8115310.svg)](https://doi.org/10.5281/zenodo.8115310)
[![arXiv](https://img.shields.io/badge/arXiv-2309.14473-b31b1b.svg)](https://arxiv.org/abs/2309.14473)
[![PyPI version](https://badge.fury.io/py/nrsur-catalog.svg)](https://badge.fury.io/py/nrsur-catalog)

This repository contains the Python package source code for the NRSurrogate Catalog API. This is a catalog of posterior samples associated with the paper "Analysis of GWTC-3 with fully precessing numerical relativity surrogate models". Install the package with
```
pip install nrsur_catalog
```

This package will allow users to download catalog data from the command line, load results, and make plots from within Python.  Please visit the [NRSurCat website](https://nrsur-catalog.github.io/NRSurCat-1/intro.html) for more information.

Docs live here:
https://nrsur-catalog.github.io/NRSurCat-1/api.html